@@ -1,6 +1,6 @@
 from PIL import Image as image_pil_main
 from PIL import ExifTags
-from PIL.Image import Image
+from PIL.Image import Image, Exif
 import cv2
 import numpy
 import requests
@@ -29,6 +29,7 @@ class UtilsImage:
     def open_image_pil(self, image_path: str, rotate_to_exif_orientation: bool = True) -> Image:
         # Open the image
         image_pil = image_pil_main.open(image_path)
+
         # If we need to rotate in align with exif data - rotate first and clear exif after
         if rotate_to_exif_orientation:
             image_pil = self.rotate_image_according_to_exif_orientation(image_pil)
@@ -38,12 +39,12 @@ class UtilsImage:
     def open_image_cv(self, image_path: str, rotate_to_exif_orientation: bool = True) -> ndarray:
         return self.convert_image_pil_to_image_cv(self.open_image_pil(image_path, rotate_to_exif_orientation=rotate_to_exif_orientation))
 
-    def save_image_pil(self, image_pil: Image, image_path: str) -> str:
+    def save_image_pil(self, image_pil: Image, image_path: str, quality: int = 100, subsampling: int = 0) -> str:
         # Make sure the image is in RGB mode
         image_extension = image_path.split('.')[-1].lower()
-        if image_extension in ['jpg', 'jpeg']:
+        if image_extension in ['jpg', 'jpeg'] and image_pil.mode.lower() != 'rgb':
             image_pil = image_pil.convert('RGB')
-        image_pil.save(image_path, quality=100)
+        image_pil.save(image_path, quality=quality, subsampling=subsampling)
         return image_path
 
     def save_image_cv(self, image_cv: ndarray, image_path: str) -> str:
@@ -88,10 +89,9 @@ class UtilsImage:
         return image
 
     def clear_exif_data(self, image_pil: Image) -> Image:
-        image_data = list(image_pil.getdata())
-        image_without_exif_pil = image_pil_main.new(image_pil.mode, image_pil.size)
-        image_without_exif_pil.putdata(image_data)
-        return image_without_exif_pil
+        if 'exif' in image_pil.info:
+            del image_pil.info['exif']
+        return image_pil
 
     def rotate_image_according_to_exif_orientation(self, image_pil: Image) -> Image:
         # Check that we have valid exif data
